@@ -21,7 +21,7 @@ use XSLoader;
 use Carp;
 use HiPi qw( :rpi :i2c );
 
-our $VERSION ='0.61';
+our $VERSION ='0.62';
 
 XSLoader::load('HiPi::BCM2835', $VERSION) if HiPi::is_raspberry_pi();
 
@@ -43,7 +43,7 @@ sub bcm2835_init {
 
 sub bcm2835_close {
     # only close in main thread which has tid of zero
-    return if threads->tid;
+    return if( $threads::threads && threads->tid );
     lock $_memmapped;
     if( $_memmapped ) {
         _hipi_bcm2835_close();
